Postie
======

*Oh yes, wait a minute Mr Postman.*

.. image:: https://pypip.in/download/postie/badge.svg
    :target: https://pypi.python.org/pypi/postie/
.. image:: https://pypip.in/version/postie/badge.svg
    :target: https://pypi.python.org/pypi/postie/
.. image:: https://travis-ci.org/tomleese/postie.svg?branch=master
    :target: https://travis-ci.org/tomleese/postie

Simple Python library to manage SMTP configurations.

For more information please refer to the online docs:

https://postie.readthedocs.org
